@@ -1,25 +1,11 @@
-"""
-Copyright 2018-2020 Skyscanner Ltd
-
-Licensed under the Apache License, Version 2.0 (the "License"); you may not use
-this file except in compliance with the License.
-You may obtain a copy of the License at
-
-http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software distributed
-under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
-CONDITIONS OF ANY KIND, either express or implied. See the License for the
-specific language governing permissions and limitations under the License.
-"""
 import re
 from typing import List, Pattern, Union, Optional
 
 from pydantic import Extra
 
-from ...types import ResolvableDate, Resolvable
-from .property import Property
-from .statement import Statement
+from pycfmodel.model.resources.properties.property import Property
+from pycfmodel.model.resources.properties.statement import Statement
+from pycfmodel.model.types import Resolvable, ResolvableDate
 
 _IAM_ACTIONS = [
     "IAM:AddClientIDToOpenIDConnectProvider",
@@ -153,6 +139,15 @@ _IAM_ACTIONS = [
 
 
 class PolicyDocument(Property):
+    """
+    Contains information about an attached policy.
+
+    Properties:
+
+    - Statement: A [statement][pycfmodel.model.resources.properties.statement.Statement] object.
+    - Version
+    """
+
     class Config(Property.Config):
         extra = Extra.allow
 
@@ -165,9 +160,27 @@ class PolicyDocument(Property):
         return self.Statement
 
     def statements_with(self, pattern: Pattern) -> List[Statement]:
+        """
+        Finds all statements which have at least one resource with the pattern.
+
+        Arguments:
+            pattern: Pattern to match.
+
+        Returns:
+            List of [statements][pycfmodel.model.resources.properties.statement.Statement].
+        """
         return [statement for statement in self._statement_as_list() if statement.resources_with(pattern)]
 
     def allowed_actions_with(self, pattern: Pattern) -> List[Statement]:
+        """
+        Finds all statements which have at least one action with the pattern.
+
+        Arguments:
+            pattern: Pattern to match.
+
+        Returns:
+            List of [statements][pycfmodel.model.resources.properties.statement.Statement].
+        """
         return [
             statement
             for statement in self._statement_as_list()
@@ -175,6 +188,15 @@ class PolicyDocument(Property):
         ]
 
     def allowed_principals_with(self, pattern: Pattern) -> List[str]:
+        """
+        Finds all allowed principals which match the pattern.
+
+        Arguments:
+            pattern: Pattern to match.
+
+        Returns:
+            List of principals.
+        """
         principals = set()
         for statement in self._statement_as_list():
             if statement.Effect == "Allow":
@@ -182,7 +204,15 @@ class PolicyDocument(Property):
         return list(principals)
 
     def non_whitelisted_allowed_principals(self, whitelist: List[str]) -> List[str]:
-        """Find non whitelisted allowed principals."""
+        """
+        Find non whitelisted allowed principals.
+
+        Arguments:
+            whitelist: List of whitelisted principals.
+
+        Returns:
+            List of principals.
+        """
         principals = set()
         for statement in self._statement_as_list():
             if statement.Effect == "Allow":
@@ -190,6 +220,15 @@ class PolicyDocument(Property):
         return list(principals)
 
     def get_iam_actions(self, difference=False) -> List[str]:
+        """
+        Find all IAM Actions which are specified in statements.
+
+        Arguments:
+            difference: when True, the behaviour changes to find the difference between all IAM Actions and those specified in the statements of the policy. Default = False.
+
+        Returns:
+            List of matching actions.
+        """
         actions = set()
         for statement in self._statement_as_list():
             for action in statement.get_action_list():
